"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var icon_1 = require("./../display/icon");
var classNames_1 = require("../../utilities/classNames");
var TabControl = /** @class */ (function (_super) {
    tslib_1.__extends(TabControl, _super);
    function TabControl(props) {
        var _this = _super.call(this, props) || this;
        _this.state = { selectedTabIndex: 0 };
        return _this;
    }
    TabControl.prototype.changeTab = function (newIndex) {
        var onTabChanged = this.props.onTabChanged;
        this.setState({ selectedTabIndex: newIndex }, function () {
            if (onTabChanged) {
                onTabChanged(newIndex);
            }
        });
    };
    TabControl.prototype.componentWillMount = function () {
        var defaultSelectedIndex = this.props.defaultSelectedIndex;
        if (defaultSelectedIndex !== undefined) {
            this.setState({ selectedTabIndex: defaultSelectedIndex });
        }
    };
    TabControl.prototype.render = function () {
        var _this = this;
        var _a = this.props, className = _a.className, children = _a.children, onTabChanged = _a.onTabChanged, tabAlignment = _a.tabAlignment, defaultSelectedIndex = _a.defaultSelectedIndex, attrs = tslib_1.__rest(_a, ["className", "children", "onTabChanged", "tabAlignment", "defaultSelectedIndex"]);
        var selectedTabIndex = this.state.selectedTabIndex;
        if (!tabAlignment) {
            tabAlignment = "left";
        }
        var classes = classNames_1.ClassHelpers.classNames(className, "tab-control", {
            "tabs-right": tabAlignment == "right",
            "tabs-left": tabAlignment == "left"
        });
        var filteredChildren = React.Children.toArray(children).filter(function (c) { return !!c; });
        return (React.createElement("div", tslib_1.__assign({}, attrs, { className: classes }),
            React.createElement("div", { className: "tab-control-header" }, filteredChildren.map(function (c, i) {
                return React.createElement("div", { className: "tab-item-header" + (selectedTabIndex === i ? ' selected' : ''), onClick: function () { return _this.changeTab(i); } },
                    c.props.icon ? React.createElement(icon_1.Icon, { className: "m-right-xsmall", icon: c.props.icon }) : null,
                    c.props.title);
            })),
            filteredChildren[selectedTabIndex]));
    };
    return TabControl;
}(React.Component));
exports.TabControl = TabControl;
var TabItem = /** @class */ (function (_super) {
    tslib_1.__extends(TabItem, _super);
    function TabItem() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TabItem.prototype.render = function () {
        var _a = this.props, className = _a.className, title = _a.title, children = _a.children, attrs = tslib_1.__rest(_a, ["className", "title", "children"]);
        return React.createElement("div", tslib_1.__assign({}, attrs, { className: "tab-content" + (className ? " " + className : '') }), children);
    };
    return TabItem;
}(React.Component));
exports.TabItem = TabItem;
